#!/bin/sh
#
# This script changes the output of find-requires to make
# sure unwelcome dependencies are not emitted.
#
# This means:
# 1) filtering out dependencies from the kvm symbol "greylist",
#    that are not provided by the rhel5 kernel package, but are
#    used by kmod-kvm
# 2) ensuring that no ksym(*) dependencies are left after the filtering
# 3) ensuring that no kernel(*) dependencies are included 
#
# Author: Eduardo Habkost <ehabkost@redhat.com>


# list of ksym(*) deps we really want to ignore:
greylist="$GREYLIST"

## run original find-requires script:
reqlist="$(/usr/lib/rpm/redhat/find-requires "$@")"

### 1) filter out ksyms from greylist:
reqlist="$(echo "$reqlist" | grep -v -x -F -f "$greylist")"


### 2) check for ksym(*) leftovers:
notgrey="$(echo "$reqlist" | grep 'ksym(')"
if [ -n "$notgrey" ];then
	echo "*** WARNING: ksym dependency not in the greylist:" $notgrey >&2
	# unfortunately non-zero exit codes of __find_requires are ignored by
	# RPM, so we can't abort the build here
fi


### 3) remove all kernel(*) dependencies that are not part of the official
###    rhel5 ABI list
reqlist="$(echo "$reqlist" | \
 sed -e '/kernel(rhel5_/{p;d;} # kernel(rhel5_*) = good
         /kernel(/{d;}         # kernel(*) = bad
         ')"


### output results
echo "$reqlist"
